@@ -14,14 +14,9 @@ def setup(context):
         try:
             if not os.path.isdir(path):
                 os.mkdir(path)
-            logger.info(
-                "No default mail path for mailmock is specified. Using %s" % path
-            )
+            logger.info(f"No default mail path for mailmock is specified. Using {path}")
         except OSError:
-            logger.error(
-                "No default mail path for mailmock is specified. Unable to create %s"
-                % path
-            )
+            logger.error(f"No default mail path for mailmock is specified. Unable to create {path}")
             exit(1)
         context.mail_path = path
     context.mail = FSInspector(context.mail_path)
